@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.9.0"
+    version = "1.9.3"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -107,14 +107,14 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         event = notification.event
         group = event.group
         project = group.project
-        self._post(group, project, event)
+        self._post(group, project)
 
     def notify_about_activity(self, activity):
         project = activity.project
         group = activity.group
-        self._post(group, project, activity)
+        self._post(group, project)
 
-    def _post(self, group, project, event=''):
+    def _post(self, group, project):
 
         custom_keyword = self.get_option("custom_keyword", project)
         # 告警次数阀值
@@ -161,11 +161,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             }
 
         }
-        # 0 - 状态为未解决，并且次数大于设定值，才告警通知
-        if group.status == 0 and group.times_seen:
+        # 0 - 状态为未解决，并且次数大于设定值，才告警通知，并且分配为空
+        if group.status == 0 and group.times_seen > number_alarm:
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
-
-        # 分配人员或清除人员均不发出告警
-        if not bool(event.data) or bool(event.data):
-            pass
